<?php
	
/**
 * Add custom fields to $item nav object
 * in order to be used in custom Walker
 *
 * @access      public
 * @since       1.0 
 * @return      void
*/
function wpi_add_menu_custom_fields( $menu_item ) {

	$menu_item->mega = get_post_meta( $menu_item->ID, '_menu_item_mega', true );
	$menu_item->bgcolor = get_post_meta( $menu_item->ID, '_menu_item_bgcolor', true );
	$menu_item->icon_code = esc_html(esc_attr(get_post_meta( $menu_item->ID, '_menu_item_icon_code', true )));
	if (strpos($menu_item->icon_code, 'fa-') === false) {
		$menu_item->icon_code = '';
	}
	
	/*
	if (!$menu_item->bgcolor) {
		$menu_item->bgcolor = get_theme_mod('main_nav_color');
		if (!$menu_item->bgcolor) {
			$menu_item->bgcolor = '#ea6153';
		}
	}
	 */
	
	return $menu_item;

}

/**
 * Save menu custom fields
 *
 * @access      public
 * @since       1.0 
 * @return      void
*/
function wpi_update_menu_custom_fields( $menu_id, $menu_item_db_id, $args ) {
	delete_post_meta($menu_item_db_id, '_menu_item_mega');
	delete_post_meta($menu_item_db_id, '_menu_item_icon_code');
	delete_post_meta($menu_item_db_id, '_menu_item_bgcolor');
	$default_color = get_theme_mod('main_nav_color');
	if (!$default_color) {
		$default_color = '#ea6153';
	}	
	
	if (isset($_REQUEST['menu-item-mega'])) {
		// Check if element is properly sent
		if ( is_array( $_REQUEST['menu-item-mega']) ) {
			if (isset($_REQUEST['menu-item-mega'][$menu_item_db_id])) {
				$value = $_REQUEST['menu-item-mega'][$menu_item_db_id];
				update_post_meta( $menu_item_db_id, '_menu_item_mega', $value );
			}
		}
	}
	if (isset($_REQUEST['menu-item-bgcolor'])) {
		// Check if element is properly sent
		if ( is_array( $_REQUEST['menu-item-bgcolor']) ) {
			if (isset($_REQUEST['menu-item-bgcolor'][$menu_item_db_id])) {
				$value = $_REQUEST['menu-item-bgcolor'][$menu_item_db_id];
				$value = strtolower($value);
				$default_color = strtolower($default_color);
				if ($value != $default_color) {
					update_post_meta( $menu_item_db_id, '_menu_item_bgcolor', $value );
				}
			}
		}
	}
	if (isset($_REQUEST['menu-item-icon-code'])) {
		// Check if element is properly sent
		if ( is_array( $_REQUEST['menu-item-icon-code']) ) {
			if (isset($_REQUEST['menu-item-icon-code'][$menu_item_db_id])) {
				$value = $_REQUEST['menu-item-icon-code'][$menu_item_db_id];
				$value = esc_html(esc_attr($value));
				if (strpos($value, 'fa-') !== false) {
					update_post_meta( $menu_item_db_id, '_menu_item_icon_code', $value );
				}
			}
		}
	}
}

/**
 * Define new Walker edit
 *
 * @access      public
 * @since       1.0 
 * @return      void
*/
function wpi_form_menu_custom_fields($walker,$menu_id) {

	return 'Wpi_Form_Menu_Custom_Fields';

}


/**
 *  /!\ This is a copy of Walker_Nav_Menu_Edit class in core
 * 
 * Create HTML list of nav menu input items.
 *
 * @package WordPress
 * @since 3.0.0
 * @uses Walker_Nav_Menu
 */
class Wpi_Form_Menu_Custom_Fields extends Walker_Nav_Menu  {
	/**
	 * @see Walker_Nav_Menu::start_lvl()
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference.
	 */
	function start_lvl( &$output, $depth = 0, $args = array() ) {
	}
	
	/**
	 * @see Walker_Nav_Menu::end_lvl()
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference.
	 */
	function end_lvl( &$output, $depth = 0, $args = array() ) {
	}
	
	/**
	 * @see Walker::start_el()
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $item Menu item data object.
	 * @param int $depth Depth of menu item. Used for padding.
	 * @param object $args
	 */
	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
	    global $_wp_nav_menu_max_depth;
	   
	    $_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;
	
	    $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

	    ob_start();
	    $item_id = esc_attr( $item->ID );
	    $removed_args = array(
	        'action',
	        'customlink-tab',
	        'edit-menu-item',
	        'menu-item',
	        'page-tab',
	        '_wpnonce',
	    );
	
	    $original_title = '';
	    if ( 'taxonomy' == $item->type ) {
	        $original_title = get_term_field( 'name', $item->object_id, $item->object, 'raw' );
	        if ( is_wp_error( $original_title ) )
	            $original_title = false;
	    } elseif ( 'post_type' == $item->type ) {
	        $original_object = get_post( $item->object_id );
	        $original_title = $original_object->post_title;
	    }
	
	    $classes = array(
	        'menu-item menu-item-depth-' . $depth,
	        'menu-item-' . esc_attr( $item->object ),
	        'menu-item-edit-' . ( ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? 'active' : 'inactive'),
	    );
	
	    $title = $item->title;
	
	    if ( ! empty( $item->_invalid ) ) {
	        $classes[] = 'menu-item-invalid';
	        /* translators: %s: title of menu item which is invalid */
	        $title = $item->title . '(' . __wpi('Invalid') .')';
	    } elseif ( isset( $item->post_status ) && 'draft' == $item->post_status ) {
	        $classes[] = 'pending';
	        /* translators: %s: title of menu item in draft status */
	        $title = $item->title . '(' . __wpi('Pending') .')';
	    }
	
	    $title = empty( $item->label ) ? $title : $item->label;
	
	    ?>
	    <li id="menu-item-<?php echo $item_id; ?>" class="<?php echo implode(' ', $classes ); ?>">
	        <dl class="menu-item-bar">
	            <dt class="menu-item-handle">
	                <span class="item-title">
						<?php 
						if ($item->icon_code) {
							echo '<i class="fa '.$item->icon_code.'"></i> ';
						}
						echo esc_html( $title ); 
						?>
					</span>
	                <span class="item-controls">
	                    <span class="item-type"><?php echo esc_html( $item->type_label ); ?></span>
	                    <span class="item-order hide-if-js">
	                        <a href="<?php
	                            echo wp_nonce_url(
	                                add_query_arg(
	                                    array(
	                                        'action' => 'move-up-menu-item',
	                                        'menu-item' => $item_id,
	                                    ),
	                                    remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
	                                ),
	                                'move-menu_item'
	                            );
	                        ?>" class="item-move-up"><abbr title="<?php echo esc_attr(__wpi('Move up')); ?>">&#8593;</abbr></a>
	                        |
	                        <a href="<?php
	                            echo wp_nonce_url(
	                                add_query_arg(
	                                    array(
	                                        'action' => 'move-down-menu-item',
	                                        'menu-item' => $item_id,
	                                    ),
	                                    remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
	                                ),
	                                'move-menu_item'
	                            );
	                        ?>" class="item-move-down"><abbr title="<?php echo esc_attr(__wpi('Move down')); ?>">&#8595;</abbr></a>
	                    </span>
	                    <a class="item-edit" id="edit-<?php echo $item_id; ?>" title="<?php echo esc_attr(__wpi('Edit Menu Item')); ?>" href="<?php
	                        echo ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? admin_url( 'nav-menus.php' ) : add_query_arg( 'edit-menu-item', $item_id, remove_query_arg( $removed_args, admin_url( 'nav-menus.php#menu-item-settings-' . $item_id ) ) );
	                    ?>"><?php echo __wpi( 'Edit Menu Item' ); ?></a>
	                </span>
	            </dt>
	        </dl>
	
	        <div class="menu-item-settings" id="menu-item-settings-<?php echo $item_id; ?>">
	            <?php if( 'custom' == $item->type ) : ?>
	                <p class="field-url description description-wide">
	                    <label for="edit-menu-item-url-<?php echo $item_id; ?>">
	                        <?php echo __wpi( 'URL' ); ?><br />
	                        <input type="text" id="edit-menu-item-url-<?php echo $item_id; ?>" class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->url ); ?>" />
	                    </label>
	                </p>
	            <?php endif; ?>
	            <p class="description description-thin">
	                <label for="edit-menu-item-title-<?php echo $item_id; ?>">
	                    <?php echo __wpi( 'Navigation Label' ); ?><br />
	                    <input type="text" id="edit-menu-item-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-title" name="menu-item-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->title ); ?>" />
	                </label>
	            </p>
	            <p class="description description-thin">
	                <label for="edit-menu-item-attr-title-<?php echo $item_id; ?>">
	                    <?php echo __wpi( 'Title Attribute' ); ?><br />
	                    <input type="text" id="edit-menu-item-attr-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-attr-title" name="menu-item-attr-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->post_excerpt ); ?>" />
	                </label>
	            </p>
	            <p class="field-link-target description">
	                <label for="edit-menu-item-target-<?php echo $item_id; ?>">
	                    <input type="checkbox" id="edit-menu-item-target-<?php echo $item_id; ?>" value="_blank" name="menu-item-target[<?php echo $item_id; ?>]"<?php checked( $item->target, '_blank' ); ?> />
	                    <?php echo __wpi( 'Open link in a new window/tab' ); ?>
	                </label>
	            </p>
	            <p class="field-css-classes description description-thin">
	                <label for="edit-menu-item-classes-<?php echo $item_id; ?>">
	                    <?php echo __wpi( 'CSS Classes (optional)' ); ?><br />
	                    <input type="text" id="edit-menu-item-classes-<?php echo $item_id; ?>" class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo $item_id; ?>]" value="<?php echo esc_attr( implode(' ', $item->classes ) ); ?>" />
	                </label>
	            </p>
	            <p class="field-xfn description description-thin">
	                <label for="edit-menu-item-xfn-<?php echo $item_id; ?>">
	                    <?php echo __wpi( 'Link Relationship (XFN)' ); ?><br />
	                    <input type="text" id="edit-menu-item-xfn-<?php echo $item_id; ?>" class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->xfn ); ?>" />
	                </label>
	            </p>
	            <p class="field-description description description-wide">
	                <label for="edit-menu-item-description-<?php echo $item_id; ?>">
	                    <?php echo __wpi( 'Description' ); ?><br />
	                    <textarea id="edit-menu-item-description-<?php echo $item_id; ?>" class="widefat edit-menu-item-description" rows="3" cols="20" name="menu-item-description[<?php echo $item_id; ?>]"><?php echo esc_html( $item->description ); // textarea_escaped ?></textarea>
	                    <span class="description"><?php echo __wpi('The description will be displayed in the menu if the current theme supports it.'); ?></span>
	                </label>
	            </p>        
	            <?php
	            /* New fields insertion starts here */
				/* ################################# */
				$default_color = get_theme_mod('main_nav_color');
				if (!$default_color) {
					$default_color = '#ea6153';
				}
	            ?>  
					<p class="field-icon-code description description-wide">
						<label for="edit-menu-item-icon-code-<?php echo $item_id; ?>">
							<?php echo __wpi( 'Font Awesome Icon Code' ); echo '. '.__wpi('Example').': <strong>fa-home</strong>. <'.'a hr'.'ef="htt'.'p://fortawesome.github.io/Font-Awesome/icons/" target="_blank">'.__wpi('Learn more').'</a> ';  ?> <br/>
							<input type="text" id="edit-menu-item-icon-code-<?php echo $item_id; ?>" value="<?php echo $item->icon_code; ?>" class="widefat code edit-menu-item-custom" name="menu-item-icon-code[<?php echo $item_id; ?>]"  /> 
						</label>
					</p>
					
					<p class="field-bg-color description description-wide">
						<label for="edit-menu-item-bgcolor-<?php echo $item_id; ?>">
							<?php echo __wpi( 'Item Background Color' ); ?> <br/>
							<input type="text" id="edit-menu-item-bgcolor-<?php echo $item_id; ?>" value="<?php echo $item->bgcolor; ?>" class="my-color-field widefat code edit-menu-item-custom" name="menu-item-bgcolor[<?php echo $item_id; ?>]" data-default-color="" /> 
						</label>
					</p>
					
					<?php if ($depth == 0) : 
						?>
						<p class="field-mega description description-wide">
							<label for="edit-menu-item-mega-<?php echo $item_id; ?>">
								<input type="checkbox" id="edit-menu-item-mega-<?php echo $item_id; ?>" class="widefat code edit-menu-item-custom" name="menu-item-mega[<?php echo $item_id; ?>]" <?php if ($item->mega) {echo 'checked="checked"';} ?> /> <?php echo __wpi( 'Active Mega Menu' ); ?>
							</label>
						</p>
					<?php endif; ?>
	            <?php
				/* ################################# */
	            /* New fields insertion ends here */
	            ?>
	            <div class="menu-item-actions description-wide submitbox">
	                <?php if( 'custom' != $item->type && $original_title !== false ) : ?>
	                    <p class="link-to-original">
	                        <?php echo __wpi('Original') . ': ' . '<a href="' . esc_attr( $item->url ) . '">' . esc_html( $original_title ) . '</a>'; ?>
	                    </p>
	                <?php endif; ?>
	                <a class="item-delete submitdelete deletion" id="delete-<?php echo $item_id; ?>" href="<?php
	                echo wp_nonce_url(
	                    add_query_arg(
	                        array(
	                            'action' => 'delete-menu-item',
	                            'menu-item' => $item_id,
	                        ),
	                        remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
	                    ),
	                    'delete-menu_item_' . $item_id
	                ); ?>"><?php echo __wpi('Remove'); ?></a> <span class="meta-sep"> | </span> <a class="item-cancel submitcancel" id="cancel-<?php echo $item_id; ?>" href="<?php echo esc_url( add_query_arg( array('edit-menu-item' => $item_id, 'cancel' => time()), remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) ) ) );
	                    ?>#menu-item-settings-<?php echo $item_id; ?>"><?php echo __wpi('Cancel'); ?></a>
	            </div>
	
	            <input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo $item_id; ?>]" value="<?php echo $item_id; ?>" />
	            <input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object_id ); ?>" />
	            <input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object ); ?>" />
	            <input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_item_parent ); ?>" />
	            <input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_order ); ?>" />
	            <input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->type ); ?>" />
	        </div><!-- .menu-item-settings-->
	        <ul class="menu-item-transport"></ul>
	    <?php
	    
	    $output .= ob_get_clean();

	}
	function end_el( &$output, $item, $depth = 0, $args = array() ) {
		$output .= "</li>\n";
	}
}

/*BACKEND REQUEST*/
// add custom menu fields to menu
add_filter( 'wp_setup_nav_menu_item', 'wpi_add_menu_custom_fields' );

// save menu custom fields
add_action( 'wp_update_nav_menu_item', 'wpi_update_menu_custom_fields', 10, 3 );

// edit menu walker
add_filter( 'wp_edit_nav_menu_walker', 'wpi_form_menu_custom_fields', 10, 2 );


/**
 * Custom Walker
 *
 * @access      public
 * @since       1.0 
 * @return      void
*/
class wpi_output_menu_custom_fields extends Walker_Nav_Menu
{
	function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0)
	{
		global $wp_query;
		$default_color = get_theme_mod('main_nav_color');
		if (!$default_color) {
			$default_color = '#ea6153';
		}
		
		$item_style = '';
		
		if (($item->bgcolor) && (strtolower($default_color) != strtolower($item->bgcolor))) {
			$item_style = ' style="background-color:'.$item->bgcolor.'"';
		}
		
		

		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		
		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="'. esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names . $item_style .'>';
		
		$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
		$attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
		$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
		$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';

		$prepend = '<strong>';
		$append = '</strong>';
		$description  = ! empty( $item->description ) ? '<span>'.esc_attr( $item->description ).'</span>' : '';

		if($depth != 0)
		{
			$description = $append = $prepend = "";
		}
		// disable unwanted elements
		$prepend = '';
		$append = '';
		$description  = '';
		
		
		$item_has_children = false;
		if (strpos($class_names, 'has-children') !== false) {
			$item_has_children = true;
		}
		
		
		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>';
		if ($item->icon_code) {
			$item_output .= '<i class="fa '.$item->icon_code.'"></i> ';
		}
		$item_output .= $args->link_before .$prepend.apply_filters( 'the_title', $item->title, $item->ID ).$append;
		$item_output .= $description.$args->link_after;
		if ($item_has_children || ($item->mega && $item->object == 'category')) {
			if ($depth == 0) {
				$item_output .= ' <i class="fa fa-angle-down menu-plus-icon"></i>';
			} else {
				$item_output .= ' <i class="fa fa-angle-right menu-plus-icon"></i>';
			}
		}
		$item_output .= ' </a>';
		$item_output .= $args->after;
		
		// mega menu start here
		// ####################
		if ($item->mega && $depth == 0) {
			$item_output .= '<div class="mega-menu mega-'.$item->object.'" '.$item_style.'><div class="mega-inner">';
			if ($item->object == 'category' && $item_has_children) {
				$item_output .= '<div class="mega-col mega-child col-1"><div class="inner">';
			}
		}
		
		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
	
	function end_el(&$output, $item, $depth = 0, $args = array())
	{
		$item_output = '';
		
		// mega menu end here
		// ###########################
		$item_has_children = false;
		$class_names = $value = '';
		$classes = empty( $item->classes ) ? array() : (array) $item->classes;
		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		if (strpos($class_names, 'has-children') !== false) {
			$item_has_children = true;
		}
		$start_col = 1;
		$post_per_page = 5;
		if ($item->mega && $depth == 0) {
			if ($item->object == 'category') {
				// close column for children
				if ($item_has_children) {
					$item_output .= '<div class="clear"></div></div></div>';
					$start_col = 2;
					$post_per_page = 4;
				}
				
				// output html for category mega data
				// ##################################
				$cargs = array (
					'ignore_sticky_posts'	=> true,
					'post_type'				=> 'post',
					'posts_per_page'		=> $post_per_page,
					'order'					=> 'DESC',
					'cat'					=> $item->object_id
				);

				$feed_query = new WP_Query( $cargs );

				if ($feed_query->have_posts()) :

					while ( $feed_query->have_posts() ) : $feed_query->the_post();
						$pid = get_the_ID();
						// preparing for flexible home layout output
						$item_review = wpi_rating_item($pid);
						$item_img_thumbnail = '<a href="'.get_permalink().'" title="'.__('Click to read', THEME_DOMAIN).'" class="item-thumbnail thumbnail">'.wpi_get_post_image($pid, 'thumbnail', array('alt' => esc_attr(get_the_title()), 'title' => esc_attr(get_the_title()))).$item_review.'</a>';

						$item_img_medium = '<a href="'.get_permalink().'" title="'.__('Click to read', THEME_DOMAIN).'" class="item-thumbnail medium">'.wpi_get_post_image($pid, 'medium', array('alt' => esc_attr(get_the_title()), 'title' => esc_attr(get_the_title()))).$item_review.'</a>';

						$item_img_large = '<a href="'.get_permalink().'" title="'.__('Click to read', THEME_DOMAIN).'" class="item-thumbnail large">'.wpi_get_post_image($pid, 'large', array('alt' => esc_attr(get_the_title()), 'title' => esc_attr(get_the_title()))).$item_review.'</a>';

						$item_title = '<h3 class="title"><a href="'.get_permalink().'" title="'.__('Click to read', THEME_DOMAIN).'">'.get_the_title().'</a></h3>';

						$item_snip = '<div class="nfont">' . wpi_get_the_snippet() . '</div>';



						$item_comments = '';
						if (comments_open()) {
							$item_comments .= '<a href="'.get_comments_link().'" class="comments"><i class="icon sprites"></i><span>'.get_comments_number().'</span></a>';
						}
						$item_views = '';
						if (get_post_meta($pid, 'post_views_count', true) && (get_theme_mod('hide_views') == false)) {
							$item_views = '<span class="views"><i class="icon sprites"></i><span>'.get_post_meta($pid, 'post_views_count', true).'</span></span>';
						}
						$item_date = '<a href="'.get_permalink().'" class="date"><span>'.get_the_date().'</span></a>';
						$item_clear = '<div class="clear"></div>';

						$item_meta = '<div class="meta">'.$item_date.$item_comments.'</div>';

						
						$item_output .=  '<div class="item mega-col col-'.$start_col.'"><div class="inner">' . $item_img_medium . $item_title  . '<div class="clear"></div></div></div>';
						$start_col++;
					endwhile;

				else:
					// message for case no post
				endif;
				wp_reset_postdata();
			}
			
			$item_output .= '<div class="clear"></div></div></div>';
		}
		$output .= apply_filters( 'walker_nav_menu_end_el', $item_output, $item, $depth, $args );
	}
}

