<?php

function wpi_pf_save($post_id) {
	/*
	* We need to verify this came from the our screen and with proper authorization,
	* because save_post can be triggered at other times.
	*/

	// Check if our nonce is set.
	if ( ! isset( $_POST['wpi_pf_nonce'] ) ) {
		return $post_id;
	}

	$nonce = $_POST['wpi_pf_nonce'];

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $nonce, 'wpi_pf' ) ) {
		return $post_id;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	// Check the user's permissions.
	if ( ($_POST['post_type'] != 'post') && ($_POST['post_type'] != 'page')) {
		return $post_id;
	}

	if ( ! current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}
  

	/* OK, its safe for us to save the data now. */
	// check custom side bar
	if (isset($_POST['wpi_pf_main_sidebar'])) {
	
		$wpi_pf_main_sidebar = sanitize_text_field( $_POST['wpi_pf_main_sidebar'] );
		update_post_meta( $post_id, 'wpi_pf_main_sidebar', $wpi_pf_main_sidebar);
	} else {
		delete_post_meta($post_id, 'wpi_pf_main_sidebar');
	}
	if (isset($_POST['wpi_pf_small_sidebar'])) {
		$wpi_pf_small_sidebar = sanitize_text_field( $_POST['wpi_pf_small_sidebar'] );
		update_post_meta( $post_id, 'wpi_pf_small_sidebar', $wpi_pf_small_sidebar);
	} else {
		delete_post_meta($post_id, 'wpi_pf_small_sidebar');
	}
	if (isset($_POST['wpi_pf_big_sidebar'])) {
		$wpi_pf_big_sidebar = sanitize_text_field( $_POST['wpi_pf_big_sidebar'] );
		update_post_meta( $post_id, 'wpi_pf_big_sidebar', $wpi_pf_big_sidebar);
	} else {
		delete_post_meta($post_id, 'wpi_pf_big_sidebar');
	}
	
}
add_action( 'save_post', 'wpi_pf_save' );
