<?php

function wpi_rating_save($post_id) {
	/*
	* We need to verify this came from the our screen and with proper authorization,
	* because save_post can be triggered at other times.
	*/

	// Check if our nonce is set.
	if ( ! isset( $_POST['wpi_rating_nonce'] ) ) {
		return $post_id;
	}

	$nonce = $_POST['wpi_rating_nonce'];

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $nonce, 'wpi_rating' ) ) {
		return $post_id;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	// Check the user's permissions.
	if ( $_POST['post_type'] != 'post') {
		return $post_id;
	}

	if ( ! current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}
  

	/* OK, its safe for us to save the data now. */
	// check rating type
	if ($_POST['wpi-rating-type']) {
		$rating_type = sanitize_text_field( $_POST['wpi-rating-type'] );
		$rating_value = 0;
		update_post_meta( $post_id, 'wpi-rating-type', $rating_type);
		update_post_meta( $post_id, 'wpi-rating-summary', sanitize_text_field( $_POST['wpi-rating-summary'] ));
	
		$feature_count = 0;
		$max_feature_count = 20;
		if ($_POST['wpi_rating_features_number']) {
			$max_feature_count = (int) sanitize_text_field( $_POST['wpi_rating_features_number'] );
		}
		for ($i = 0; $i < $max_feature_count; $i++) {
			if (	($_POST['wpi-rating-'.$rating_type.'-feature-name_'.$i]) &&
				($_POST['wpi-rating-'.$rating_type.'-feature-value_'.$i])) {
				if (is_numeric($_POST['wpi-rating-'.$rating_type.'-feature-value_'.$i])) {
					update_post_meta( $post_id, 'wpi-rating-'.$rating_type.'-feature-name_'.$i, sanitize_text_field( $_POST['wpi-rating-'.$rating_type.'-feature-name_'.$i])); 
					$feature_value = (float) sanitize_text_field( $_POST['wpi-rating-'.$rating_type.'-feature-value_'.$i]);
					// validate feature value
					if ($rating_type == 'point') {
						if ($feature_value < 0) {
							$feature_value = 0;
						}
						if ($feature_value > 10) {
							$feature_value = 10;
						}
					} else if ($rating_type == 'percent') {
						if ($feature_value < 0) {
							$feature_value = 0;
						}
						if ($feature_value > 100) {
							$feature_value = 100;
						}
					}
					update_post_meta( $post_id, 'wpi-rating-'.$rating_type.'-feature-value_'.$i, $feature_value);
					// convert rating value into one standard
					if ($rating_type == 'stars') {
						$feature_value *= 20;
					} else if ($rating_type == 'point') {
						$feature_value *= 10;
					}
					$rating_value += $feature_value;
					$feature_count++;
				}
			}	
		}
		update_post_meta( $post_id, 'wpi_rating_features_number', $feature_count); 
		if (($feature_count == 0) || (!is_numeric($feature_count))) {
			$rating_value = 0;
		} else {
			$rating_value /= ((float) $feature_count);
		}
		update_post_meta( $post_id, 'wpi_rating_value', $rating_value); 
	} else {
		// DELETE RATING SYSTEM WHEN HAVE DISABLE RATING
		delete_post_meta($post_id, 'wpi_rating_value');
	}
	

}
add_action( 'save_post', 'wpi_rating_save' );
