<?php
// http://xref.wordpress.org/tags/3.6.1/WordPress/Widgets/WP_Widget.html#WP_Widget
class Wpi_Widget_Builder {
	// CLASS GLOBAL DATA HOLDER
	// hold WP_Widget object to reuse its methods
	var $obj;

	// hold widget options and fields defines
	/*
	 * DEFINE EXAMPLE (title field is auto, not need to define
	 * array(
	 *	'id'	=>	***,
	 *	'name'	=>	***,
	 *	'desc'	=>	***,
	 *	'instance => array(
	 *		array(
	 *			'id'		=>	***,
	 *			'label'		=>	***,
	 *			'type'		=>	text/select/textarea/radio/checkbox/color/,
	 *			'default'	=>	****,
	 *			'choices'	=>	array(
	 *				'key'	=>	****
	 *			)
	 *		),
	 *	),
	 * );
	 */
	var $define;
	
	// THIS FUNCTION RUN WHEN CREATE CLASS VARIABLE
	// we will save wp_widget_object and its define array to create it
	function __construct(&$wp_widget_object, $define_array) {
		// save widget object to create it
		$this->obj = $wp_widget_object;
		// value array
		if (!isset($define_array['name'])) {
			$define_array['name'] = 'WPI ' . $define_array['id'];
		}
		if (!isset($define_array['desc'])) {
			$define_array['desc'] = 'Just a Widget of Wpi Designer';
		}
		if (!isset($define_array['instance'])) {
			$define_array['instance'] = array();
		}
		$define_array['instance'] = wp_parse_args($define_array['instance'], array(
			array(
				'id'	=>	'title',
				'label'	=>	'Title',
			)
		));
		
		// save defines
		$this->define = $define_array;
		
		// create widget base on widget object
		$this->obj->WP_Widget(
			$define_array['id'], 
			'&#9733;&nbsp; ' . __wpi($define_array['name']), 
			array('description' => __wpi($define_array['desc']))
		);
	}
	
	// valide instance values (must compare type, if not match, use default or blank)
	function valid($instance) {
		foreach ($this->define['instance'] as $inst) {
			$id = $inst['id'];
			if (!isset($inst['type'])) {
				$inst['type'] = 'text';
				if (strpos($inst['id'], 'category_check') !== false || strpos($inst['id'], 'cat_check') !== false ) {
					$inst['type'] = 'category_check';
				} else if (strpos($inst['id'], 'cat') !== false) {
					$inst['type'] = 'category';
				} else if (strpos($inst['id'], 'author') !== false) {
					$inst['type'] = 'author';
				} else if (strpos($inst['id'], 'color') !== false) {
					$inst['type'] = 'color';
				}
			}
			$instance[$id] = wpi_safe_array_get($instance, $id);
			if (!$instance[$id] && isset($inst['default'])) {
				$instance[$id] = $inst['default'];
			}
			
			if ($inst['type'] == 'category_check') {
				if (!is_array($instance[$id])) {
					$instance[$id] = array();
				}
			} else if (isset($inst['default'])) {
				if (gettype($inst['default']) == 'integer' && (!is_numeric ($instance[$id]))) {
					$instance[$id] = $inst['default'];
				} else {
					settype($instance[$id], gettype($inst['default']));
				}
			} else if ($inst['type'] == 'category' || $inst['type'] == 'author') {
				if (!is_numeric ($instance[$id])) {
					$instance[$id] = 0;
				} else {
					$instance[$id] = (int) $instance[$id];
				}
			}
			
			if ($inst['type'] == 'color' && $instance[$id] == $inst['default']) {
				$instance[$id] = '';
			}
		}
		return $instance;
	}
	
	// create form base on define array
	function form($instance) {
		$instance = $this->valid($instance);
		
		// show instance in form
		$o = $this->obj;
		foreach ($this->define['instance'] as $inst):
			$id = $inst['id'];
			if (!isset($inst['label'])) {
				$inst['label'] = ucfirst($inst['id']);
				$inst['label'] = str_replace('_', ' ', $inst['label']);
			}
			if (!isset($inst['type'])) {
				$inst['type'] = 'text';
				if (strpos($inst['id'], 'category_check') !== false || strpos($inst['id'], 'cat_check') !== false ) {
					$inst['type'] = 'category_check';
				} else if (strpos($inst['id'], 'cat') !== false) {
					$inst['type'] = 'cat';
				} else if (strpos($inst['id'], 'author') !== false) {
					$inst['type'] = 'author';
				} else if (strpos($inst['id'], 'color') !== false) {
					$inst['type'] = 'color';
				}
			}
			?>
			<p>
				<label for="<?php echo $o->get_field_id( $id ); ?>">
				<?php
				switch (strtolower($inst['type'])) :
					// TEXTAREA
					case 'textarea':
						echo __wpi( $inst['label'] ) . '<br/><textarea class="widefat" id="'. $o->get_field_id( $id ) .'" name="'. $o->get_field_name( $id ) .'">'.$instance[$id].'</textarea>';
						break;
					// TEXT #############################
					case 'text':
					default:
						echo __wpi( $inst['label'] ) . '<br/><input class="widefat" id="'. $o->get_field_id( $id ) .'" name="'. $o->get_field_name( $id ) .'" type="text" value="'. esc_attr( $instance[$id] ) .'" />';
						break;
					
					// CHECKBOX ###############################
					case 'checkbox':
						
						echo '<input class="checkbox" type="checkbox"'. (( $instance[$id] )? ' checked':'') .' id="'. $o->get_field_id( $id ) .'" name="'. $o->get_field_name( $id ) .'"></input>'. __wpi( $inst['label'] );
						break;
					
					// SELECT ##################################
					case 'select':
						echo __wpi( $inst['label'] ).'<br/><select name="'.$o->get_field_name($id) .'" class="widefat">';
						foreach ($inst['choices'] as $key => $value) {
							echo '<option value="'.esc_attr($key).'" ';
							if (isset($inst['default'])) {
								settype($key, gettype($inst['default']));
							}
							if ($key == $instance[$id]) {
								echo ' selected="selected"';
							}
							echo '>'. __wpi($value) . '</option>';
						}
						echo '</select>';
						break;
						
					// CATEGORY LIST #####################################
					case 'cat':
					case 'cateogry':
						$args = array(
						'type'                     => 'post',
						'child_of'                 => 0,
						'orderby'                  => 'name',
						'order'                    => 'ASC',
						'hide_empty'               => 1,
						'hierarchical'             => 1,
						'taxonomy'                 => 'category');
						$categories = get_categories( $args ); 
						if (!$instance[$id]) {
							$instance[$id] = 0;
						}
						$instance[$id] = (int) $instance[$id];
						echo __wpi( $inst['label'] ).'<br/><select name="'.$o->get_field_name($id) .'" class="widefat">
							<option value="0" ';
						if($instance[$id]==0)  {echo ' selected="selected"';}
						echo '>' . __wpi('All Categories') . '</option>';
						
						foreach($categories as $category) {
							echo '<option value="'. $category->term_id .'" ';
							if($category->term_id==$instance[$id])  {echo 'selected="selected"';} 
							echo '>'.$category->cat_name .'</option>';
						}
						echo '</select>';
						break;
						
					// CATEGORY CHECK LIST #####################################
					case 'cat_check':
					case 'category_check':
						$args = array(
						'type'                     => 'post',
						'child_of'                 => 0,
						'orderby'                  => 'name',
						'order'                    => 'ASC',
						'hide_empty'               => 1,
						'hierarchical'             => 1,
						'taxonomy'                 => 'category');
						$categories = get_categories( $args ); 
						
						
						$cate_str = '';
						if (is_array($instance[$id])) {
							foreach($instance[$id] as $value) {
								$cate_str .= '['.$value.']';
							}
						}
						
						echo __wpi( $inst['label'] ).'<br/>';
						echo '<span class="cate-check-list-wrapper">';
						$index = 0;
						foreach($categories as $category) {
							echo '<span class="cate-check-item" for="'.$id.'['.$index.']"><input id="'. $o->get_field_id( $id ) .'['.$index.']" name="'. $o->get_field_name( $id ) .'['.$index.']" type="checkbox" class="checkbox" value="'. $category->term_id .'" ';
							if(strpos($cate_str, '['.$category->term_id.']') !== false)  {
								echo 'checked="checked"';
							} 
							echo '/>'.$category->cat_name.'</span>';
							$index++;
						}
						echo '</span>';
						break;
						
					// AUTHOR LIST ###############################
					case 'author':
					case 'aut':
					case 'au':
						
						
						if (!$instance[$id]) {
							$instance[$id] = 0;
						}
						$instance[$id] = (int) $instance[$id];
						echo __wpi( $inst['label'] ).'<br/><select name="'.$o->get_field_name($id) .'" class="widefat">
							<option value="0" ';
						if($instance[$id]==0)  {echo ' selected="selected"';}
						echo '>' . __wpi('All Authors') . '</option>';
						
						$users = get_users(array());
						if (!empty($users)) {
							foreach ($users as $user) {
								if (count_user_posts($user->ID)) {
									echo '<option value="'. $user->ID .'" ';
									if($user->ID==$instance[$id])  {echo 'selected="selected"';} 
									echo '>'.$user->display_name .'</option>';
								}
							}
						}
						
						
						echo '</select>';
						break;
					
					// COLOR #############################
					case 'color':
						if ($instance[$id] == '') {
							$instance[$id] = $inst['default'];
						}
						echo __wpi( $inst['label'] ) . '<br/><input class="my-color-field" id="'. $o->get_field_id( $id ) .'" name="'. $o->get_field_name( $id ) .'" type="text" value="'. esc_attr( $instance[$id] ) .'" '.((isset($inst['default']))? 'data-default-color="'.$inst['default'].'"' : '').'/>';
						break;
				endswitch;
				?>
				</label>
			</p>
			
			<?php
		endforeach;

	}
	
	// update widget controls
	function update($new_instance, $old_instance) {
		
		$new_instance = $this->valid($new_instance);
		// save new instance
		$instance = $old_instance;
		foreach ($new_instance as $key => $value) {
			$instance[$key]	= $new_instance[$key];
		}
		return $instance;
	}
	
	
}