<?php
class Login_Form_Widget extends WP_Widget {

	/** Main */
	function __construct() {
		global $widget_prefix_name;
		parent::__construct(
			'wpi_login_form', // Base ID
			$widget_prefix_name . __wpi('Login Form'), // Name
			array( 'description' => __wpi('Show Login / Register form'), ) // Desc
		);
	}


	/** use this function to decide how the widget settings 
	will display in your admin dashboard */
	public function form( $instance ) {
		$title = '';
		$title = esc_attr(wpi_safe_array_get($instance, 'title'));
				
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php echo __wpi( 'Title' ); ?> 
			
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			</label>
		</p>
		
		
		<?php 
	}

	/** use this function to decide the way widget data will
	be saved after admin update widget data */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		return $instance;
	}
	
	
	/** use this function to decide how the widget
	will display in your theme */
	public function widget( $args, $instance ) {
		extract( $args );
		$title = '';
		$title = esc_attr(wpi_safe_array_get($instance, 'title'));
		$title = apply_filters('widget_title', $title);
		
		// Show HTML
		echo $before_widget;
		if ($title == '') {
			$title = __wpi('Log In');
		}
		if (is_user_logged_in()) {
			$current_user = wp_get_current_user();
			if ($current_user instanceof WP_User ) {
				$user_avatar = '<a href="'.admin_url( 'profile.php' ).'" class="comment-avatar item-thumbnail">'.get_avatar($current_user->user_email,48).'</a>';
				
				echo $before_title .  __wpi('Howdy'). $after_title;
			
				echo '<div class="table logged">
	<div class="tr">
		<div class="td" style="width: 1%">'.$user_avatar.'</div>
		<div class="td" style="width:100%"><div class="content">
			<strong class="user-name">'.$current_user->display_name.'</strong>
			<a class="profile-link" href="'.admin_url( 'profile.php' ).'"><i class="fa fa-pencil-square-o"></i> '. __wpi('Edit profile').'</a>
			<a href="'.wp_logout_url(site_url( $_SERVER['REQUEST_URI'] )).'"><i class="fa fa-power-off"></i> '. __wpi('Log out').'</a>
		</div></div>
	</div>
</div>';
			}
		} else {
			echo $before_title . '<span class="login title-inner">'. $title .'</span>' . $after_title;
		
			$args = array(
				'form_id' => 'loginform',
				'label_username' => __wpi( 'Username' ),
				'label_password' => __wpi( 'Password' ),
				'label_remember' => __wpi( 'Remember Me' ),
				'label_log_in' => $title,
				'id_username' => 'user_login',
				'id_password' => 'user_pass',
				'id_remember' => 'rememberme',
				'id_submit' => 'wp-submit'
			);

			wp_login_form($args);
			echo '<div class="clear"></div>';
			if (get_option( 'users_can_register' )) {
			 echo '<a class="register title-inner" href="'.wp_registration_url().'"><i class="fa fa-user"></i> ' . __wpi('Register') . '</a> ';
			}
			echo '<a href="'.esc_url(wp_lostpassword_url(site_url( $_SERVER['REQUEST_URI'] ))).'" class="forgot-pass"><i class="fa fa-unlock-alt"></i> '.__wpi('Lost your password?').'</a>';
		}
		
		
		
		echo $after_widget;
	}
}

// register News_Article_Box_Widget
add_action('widgets_init', create_function('', 'return register_widget("Login_Form_Widget");'));
