<?php
class Recent_Comments_Widget extends WP_Widget {

	/** Main */
	function __construct() {
		global $widget_prefix_name;
		parent::__construct(
			'wpi_recent_comments', // Base ID
			$widget_prefix_name . __wpi('Recent Comments'), // Name
			array( 'description' => __wpi('Show Recent Comments'), ) // Desc
		);
	}


	/** use this function to decide how the widget settings 
	will display in your admin dashboard */
	public function form( $instance ) {
		$title = '';
		$title = esc_attr(wpi_safe_array_get($instance, 'title'));
		
		$count = esc_attr(wpi_safe_array_get($instance, 'count' ));
		if (!$count) {
			$count = 5;
		}
		$count = (int) $count;
		
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php echo __wpi( 'Title' ); ?> 
			
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			</label>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php echo __wpi( 'Comment count' ); ?> 
			
				<input class="widefat" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" type="text" value="<?php echo esc_attr( $count ); ?>" />
			</label>
		</p>
		
		<?php 
	}

	/** use this function to decide the way widget data will
	be saved after admin update widget data */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['count'] = strip_tags($new_instance['count']);
		return $instance;
	}
	
	
	/** use this function to decide how the widget
	will display in your theme */
	public function widget( $args, $instance ) {
		extract( $args );
		$title = '';
		$title = esc_attr(wpi_safe_array_get($instance, 'title'));
		$title = apply_filters('widget_title', $title);
		
		$count = esc_attr(wpi_safe_array_get($instance, 'count' ));
		if (!$count) {
			$count = 5;
		}
		$count = (int) $count;
		
		echo $before_widget;
		if ($title) {
			echo $before_title . $title . $after_title;
		} else {
			echo '<div class="widget-content">';
		}
		// Show HTML
		echo '<div class="comment-data">';
		
		/*QUERY*/
		// common query
		$args = array(
			'number' => $count,
			'status' => 'approve',
			'type'		=>	'comment'
		);
		$comments = get_comments($args);
		if (count($comments)): 
			$counter = 0;
			foreach ($comments as $comment) :
				$post_id = $comment->comment_post_ID;

				$item_thumbnail = '<a href="'.get_permalink($post_id).'#comment-'.$comment->comment_ID.'" class="comment-avatar item-thumbnail">'.get_avatar($comment->comment_author_email,50).'</a>';

				$item_title = '<strong class="comment-name">'.$comment->comment_author.'</strong>';

				$snip = strip_tags($comment->comment_content);
				if (strlen($snip) > 50) {
					mb_internal_encoding('UTF-8');
					mb_http_output('UTF-8');
					mb_http_input('UTF-8');
					mb_language('uni');
					mb_regex_encoding('UTF-8');
					$snip = mb_substr($snip, 0, 50) . '...';	
				}
				$item_snip = '<a class="recent-comment-snip" href="'.get_permalink($post_id).'#comment-'.$comment->comment_ID.'"><span class="color-hover">'. $snip . '</span></a>';

				echo '<div class="comment-item comment-item-'.$counter.'">'.$item_thumbnail.'<div class="body">
	<div class="arrow"></div>
	<div class="body-inner">
		'.$item_title.$item_snip.'
	</div>
</div><div class="clear"></div></div>';
				$counter++;
			endforeach;
		else:
			echo '<p><em>'.__wpi('Have no comments').'</em></p>';
		endif;
		wp_reset_postdata();
		
		echo '<div class="clear"></div></div>';
		
		if (!$title) {
			echo '<div class="clear"></div></div>';
		}
		echo $after_widget;
		
		
	}
}

// register News_Article_Box_Widget
add_action('widgets_init', create_function('', 'return register_widget("Recent_Comments_Widget");'));
